"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CredentialsModule = void 0;
const FeatureRegistry_1 = require("../../FeatureRegistry");
const MessageHandlerRegistry_1 = require("../../MessageHandlerRegistry");
const models_1 = require("../../models");
const CredentialsApi_1 = require("./CredentialsApi");
const CredentialsModuleConfig_1 = require("./CredentialsModuleConfig");
const services_1 = require("./protocol/revocation-notification/services");
const v2_1 = require("./protocol/v2");
const repository_1 = require("./repository");
class CredentialsModule {
    constructor(config) {
        // Infer Api type from the config
        this.api = CredentialsApi_1.CredentialsApi;
        this.config = new CredentialsModuleConfig_1.CredentialsModuleConfig({
            ...config,
            // NOTE: the credentialProtocols defaults are set in the CredentialsModule rather than the CredentialsModuleConfig to
            // avoid dependency cycles.
            credentialProtocols: config?.credentialProtocols ?? [new v2_1.V2CredentialProtocol({ credentialFormats: [] })],
        });
    }
    /**
     * Registers the dependencies of the credentials module on the dependency manager.
     */
    register(dependencyManager) {
        // Config
        dependencyManager.registerInstance(CredentialsModuleConfig_1.CredentialsModuleConfig, this.config);
        // Services
        dependencyManager.registerSingleton(services_1.RevocationNotificationService);
        // Repositories
        dependencyManager.registerSingleton(repository_1.CredentialRepository);
    }
    async initialize(agentContext) {
        const messageHandlerRegistry = agentContext.dependencyManager.resolve(MessageHandlerRegistry_1.MessageHandlerRegistry);
        const featureRegistry = agentContext.dependencyManager.resolve(FeatureRegistry_1.FeatureRegistry);
        featureRegistry.register(new models_1.Protocol({
            id: 'https://didcomm.org/revocation_notification/1.0',
            roles: ['holder'],
        }), new models_1.Protocol({
            id: 'https://didcomm.org/revocation_notification/2.0',
            roles: ['holder'],
        }));
        // Protocol needs to register feature registry items and handlers
        for (const credentialProtocol of this.config.credentialProtocols) {
            credentialProtocol.register(messageHandlerRegistry, featureRegistry);
        }
    }
}
exports.CredentialsModule = CredentialsModule;
//# sourceMappingURL=CredentialsModule.js.map